Download PySkein — PySkein v0.5 documentation

### Navigation

- index
- previous |
- PySkein v0.5 documentation »

# Download PySkein

- If you have an older version of PySkein installed, please make sure to delete “skein.*” from your Python “site-packages” directory before installing PySkein 0.5!

- Source distribution: pyskein-0.5.tar.gz (sig)

- Windows installer (only for Python 3.1): pyskein-0.5.win32-py3.1.exe (sig)

- New in PySkein 0.5
    - Updated rotation constants to new Skein specification (version 1.2)
    - Added implementation of Skein PRNG

## Previous versions

- pyskein-0.4.tar.gz (sig)
- pyskein-0.4.win32-py3.1.exe (sig)
- pyskein-0.3.1.tar.gz (sig)
- pyskein-0.3.1.win32-py3.1.exe (sig)
- pyskein-0.3.tar.gz (sig)
- pyskein-0.2.tar.gz (sig)
- pyskein-0.1.tar.gz (sig)

## Changes

0.4
  - Hashing with personalization string
  - Hashing with nonce value
0.3.1
  - Improved demo script “threefish”
  - Better compatibility with Python 3.1
0.3
  - Threefish block decryption
  - Demo scripts “skeinsum” and “threefish”
0.2
  - Support for message authentication codes
  - Threefish block encryption (but no decryption)
  - Fixed one or two reference leaks
0.1
  - Skein-256, Skein-512, and Skein-1024 hashing

### Navigation

- index
- previous |
- PySkein v0.5 documentation »